+++
title = "Transconductance Amplifiers"
author = ["Dehaeze Thomas"]
draft = false
category = "equipment"
+++

Tags
: [Electronics]({{< relref "electronics.md" >}}), [Voice Coil Actuators]({{< relref "voice_coil_actuators.md" >}})


## Description {#description}

A Transconductance Amplifier converts the control voltage into current with a current source characteristic.

Such a converter is called a voltage-to-current converter, also named a voltage-controlled current source or _transconductance_ amplifier.

Such amplifier is used to control motors (e.g. voice coil, BLDC, stepper motors, ...).


## Specifications {#specifications}


### Noise {#noise}

```matlab
BL = 20; % [N/A]
m = 1; % [kg]
```

```matlab
freq = logspace(0,4,1000); % [Hz]

%% Current noise of the amplifier
I_asd = 1e-6*ones(size(freq)); % [A/sqrt(Hz)]
```

```matlab
x_asd = I_asd*(BL/m)./(2*pi*freq).^2;
```

```matlab
figure;
plot(freq, x_asd)
xlabel("Frequency [Hz]");
ylabel("ASD [$m/\sqrt{Hz}$]");
set(gca, 'Xscale', 'log');
set(gca, 'Yscale', 'log');
```

```matlab
figure;
plot(freq, sqrt(flip(-cumtrapz(flip(freq), flip(x_asd.^2)))))
xlabel("Frequency [Hz]");
ylabel("Cumulative Amplitude Spectrum [m rms]");
set(gca, 'Xscale', 'log');
set(gca, 'Yscale', 'log');
```


## Manufacturers {#manufacturers}

<a id="table--tab:table-name"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:table-name">Table 1</a>:</span>
  Drivers with integrated controllers
</div>

| Model                                                                                                                             | Manufacturer    | Linear / PWM | Axes           | Interfaces    | Feedback     | Current Bandwidth | ASD at 1kHz [A/sqrt(Hz)] |
|-----------------------------------------------------------------------------------------------------------------------------------|-----------------|--------------|----------------|---------------|--------------|-------------------|--------------------------|
| [Apogee](https://prodrive-technologies.com/motion/products/servo-drives/apogee-kepler-series/)                                    | Prodrive        | PWM          | 1 to 3         | +/-10V 16bits | Encoder      | 7kHz              | 1e-6                     |
| [S3-400/8](https://prodrive-technologies.com/motion/products/servo-drives/cygnus-series/)                                         | Prodrive        | PWM          | 1              | +/-10V        | Encoder      | 1kHz              | 1e-4                     |
| [LWM7S](https://www.maccon.co.uk/linear-servo-amplifier.html)                                                                     | Macon           | Linear       | 1              |               | Encoder/Hall |                   |                          |
| [Soloist ML](https://www.aerotech.com/product/motion-control-platforms/soloist-ml-controller-and-linear-digital-drive/)           | Aerotech        | Linear       | 1              | +/-10V 16bits | Encoder/Hall |                   |                          |
| [Automation1 XL4s](https://www.aerotech.com/product/motion-control-platforms/automation1-xl4s-high-performance-voice-coil-drive/) | Aerotech        | Linear       | 1 (voice coil) | +/-10V 16bits | ?            |                   |                          |
| [Automation1 XL2e](https://www.aerotech.com/product/motion-control-platforms/automation1-xl4s-high-performance-voice-coil-drive/) | Aerotech        | Linear       | 1              | +/-10V 16bits | Encoder/Hall | 2.5kHz            |                          |
| [EM-356B](https://electromen.com/en/products/item/motor-controllers/brushless-dc-motor/EM-356B)                                   | Electromen      | PWM          | 1              | 0-10V         | Hall         |                   |                          |
| [azbh10a4](https://www.a-m-c.com/product/azbh10a4/)                                                                               | AMC             | PWM          | 1              | +/-10V        | Hall         |                   |                          |
| [X-MCC](https://www.zaber.com/products/controllers-joysticks/X-MCC)                                                               | Zaber           | ??           | 1 to 4         |               |              |                   |                          |
| [TA310](https://www.trustautomation.com/products/linear-drives/ta310-linear-drive/)                                               | TrustAutomation | Linear       | 1              | +/-10V        | Hall         | 5kHz              |                          |

<a id="table--tab:table-name"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:table-name">Table 2</a>:</span>
  Pure Drivers
</div>

| Model                                                                                                                                                                       | Manufacturer    | Linear / PWM | Axes                   | Interfaces | Current Bandwidth | Max Current | ASD at 1kHz [A/sqrt(Hz)] |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------|--------------|------------------------|------------|-------------------|-------------|--------------------------|
| [LA300](https://varedan.com/product/analog-linear-servo-amplifiers/la-300-analog-linear-servo-amplifier/)                                                                   | Varedan         | Linear       | 3                      | +/-10V     | 10kHz             | 4A          |                          |
| [LA24](https://www.cedrat-technologies.com/en/technologies/actuators/magnetic-actuators-motors.html)                                                                        | Cedrat          | Linear       | 3                      | +/-10V     | 35kHz             | 1.5A        |                          |
| [CMAu10](https://www.cedrat-technologies.com/en/products/magnetic-controllers/oem-amplifiers.html)                                                                          | Cedrat          | Linear       | 1                      | +/-10V     | 5kHz              | 0.5A        |                          |
| [TA115](https://www.trustautomation.com/products/linear-drives/ta115-linear-drive/) and [TA105](https://www.trustautomation.com/products/linear-drives/ta105-linear-drive/) | TrustAutomation | Linear       | 1                      | +/-10V     | 5kHz              |             | 1e-6                     |
| [SMA6520](https://www.glentek.com/shop/?swoof=1&product_cat=linear-brushless-series&really_curr_tax=21-product_cat)                                                         | Glentek         | Linear       | 1 Brushless (3 phases) | +/-10V     | 10kHz             |             |                          |
| [SMA5005](https://www.glentek.com/shop/?swoof=1&product_cat=linear-brush-series&really_curr_tax=21-product_cat)                                                             | Glentek         | Linear       | 1                      | +/-10V     | 10kHz             |             |                          |


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
</div>
